require 'net/http'
require 'uri'
require 'json'

module Rik
  
  class API
    
    class Error < RuntimeError
      attr_accessor :fault_code, :fault
      
      def initialize(fault, fault_code)
        @fault = fault
        @fault_code = fault_code
      end
    end
    
    VALID_OPTIONS_KEYS = [
      :apikey,
      :login,
      :password].freeze
      
    attr_accessor *VALID_OPTIONS_KEYS
    
    # http://engine.qik.com/api/jsonrpc
    BASE_URI = 'http://72.5.78.64/api/jsonrpc'.freeze
    
    def initialize
      @uri = URI.parse(BASE_URI)
      reset
    end
    
    def call(method, *params)
      body = {
        :method => method,
        :params => params || []
      }.to_json
      
      http = Net::HTTP.new(@uri.host, @uri.port)
      request = Net::HTTP::Post.new("#{@uri.request_uri}?apikey=#{@apikey}")
      
      request.body = body
      response = http.request(request)
      answer = JSON.parse(response.body)
      
      if answer[0] == nil
        raise Error.new(answer['fault'], answer['faultCode']),
          answer['faultString']
      end
      
      answer[0]
    end
    
    def configure
      yield self
    end
    
    def reset
      @apikey = '94e147c9aff4392f'
      @login = nil
      @password = nil
    end
  end
end