module Rik
  class Client
    
    module Stream
      
      def subscribe_follow_streams(*args)
        options = args.last.is_a?(Hash) ? args.pop : {}
        
        filter_shared = options[:filter_shared]
        filter_shared = true if filter_shared.nil?
        limit = options[:limit] || 10
        
        begin
          call 'qik.stream.subscribe_follow_streams', create, 
            filter_shared, limit
        
        rescue Rik::API::Error => error
          unless error.fault_code == 2002 
            STDERR << error
            nil
          else # invalid session lets renew
            recreate
            retry
          end
        end
      end
      
      def subscribe_own_user_streams(*args)
        options = args.last.is_a?(Hash) ? args.pop : {}
        
        limit = options[:limit] || 10
        
        begin
          call 'qik.stream.subscribe_own_user_streams', create, limit
          
        rescue Rik::API::Error => error
          unless error.fault_code == 2002 
            STDERR << error
            nil
          else # invalid session lets renew
            recreate
            retry
          end
        end
      end
      
      def subscribe_public_streams(*args)
        options = args.last.is_a?(Hash) ? args.pop : {}
        
        recent = options[:recent]
        live = options[:live]
        limit = options[:limit]
        
        begin
          if recent || (!recent && !live)
            call 'qik.stream.subscribe_public_recent', create, limit || 50
          else
            call 'qik.stream.subscribe_public_live', create, limit || 10
          end
          
        rescue Rik::API::Error => error
          unless error.fault_code == 2002 
            STDERR << error
            nil
          else # invalid session lets renew
            recreate
            retry
          end
        end
      end
      
      def subscribe_user_streams(*args)
        options = args.last.is_a?(Hash) ? args.pop : {}
        
        username = args.first
        
        do_public = options[:public] ? '_public' : ''
        limit = options[:limit] || 10
        
        begin
          call "qik.stream.subscribe#{do_public}_user_streams", create, 
            username, limit
            
        rescue Rik::API::Error => error
          unless error.fault_code == 2002 
            STDERR << error
            nil
          else # invalid session lets renew
            recreate
            retry
          end
        end
      end
    end
  end
end
